@@ -15,8 +15,9 @@ class GoDiagramParser(object):
         self.initial_black = set()
         self.initial_white = set()
         self.sequence_moves = {}
-        self.annotated_points = {}
-        self.first_player = None
+        self.marked_coordinates = {}
+        self.first_player = 'black'
+        self.second_player = 'white'
         self._state = 'header'
 
     def board_size(self):
@@ -37,10 +38,12 @@ class GoDiagramParser(object):
         if line.startswith(self.line_prefix + 'W'):
             header_line = True
             self.first_player = 'white'
+            self.second_player = 'black'
             prefix = self.line_prefix + 'W'
         elif line.startswith(self.line_prefix + 'B'):
             header_line = True
             self.first_player = 'black'
+            self.second_player = 'white'
             prefix = self.line_prefix + 'B'
         elif line.startswith(self.line_prefix):
             prefix = self.line_prefix
@@ -85,14 +88,42 @@ class GoDiagramParser(object):
                 coord = (i, self.board_height - 1)
                 if point == 'X':
                     self.initial_black.add(coord)
+        	    self.marked_coordinates[coord] = ('black', None)
                 elif point == 'O':
                     self.initial_white.add(coord)
-                elif point in list('1234567890'):
-                    if point == '0':
-                        point = '10'
-                    self.sequence_moves[int(point)] = coord
-                elif point in list('abcdefghijklmnopqrstuvwxyz'):
-                    self.annotated_points[point] = coord
+        	    self.marked_coordinates[coord] = ('white', None)
+                elif all(c in list('1234567890') for c in point):
+                    point = int(point)
+                    if point == 0:
+                        point = 10
+                    self.sequence_moves[point] = coord
+        	    if point % 2:
+        	        player = self.first_player
+        	    else:
+        		player = self.second_player
+        	    self.marked_coordinates[coord] = (player, str(point))
+ 
+                elif point in list(u'abcdefghijklmnopqrstuvwxyz'):
+		    # empty point annotations
+		    self.marked_coordinates[coord] = (u'empty', point)
+		elif point in list(u'BW#@YQZPCSTM'):
+                    translations = {
+                        'B': (u'black', u'O'),
+                        'W': (u'white', u'O'), 
+                        'C': (u'empty', u'O'), #MEDIUM SMALL WHITE CIRCLE, WHITE CIRCLE?
+                        '#': (u'black', u'\N{BLACK MEDIUM SQUARE}'), 
+                        '@': (u'white', u'\N{BLACK MEDIUM SQUARE}'),
+                        'S': (u'empty', u'\N{BLACK MEDIUM SQUARE}'), # BLACK SQUARE
+                        'Y': (u'black', u'\N{BLACK UP-POINTING TRIANGLE}'),
+                        'Q': (u'white', u'\N{BLACK UP-POINTING TRIANGLE}'),
+                        'T': (u'empty', u'\N{BLACK UP-POINTING TRIANGLE}'),
+                        'Z': (u'black', u'X'),
+                        'P': (u'white', u'X'),
+                        'M': (u'white', u'X'),
+                    }
+
+		    # stone annotations
+        	    self.marked_coordinates[coord] = translations[point]
                 elif point in list('.,'):
                     #Empty point
                     pass
